@@ -526,6 +526,8 @@ class SynSet:
                 outFile.write("<ILR>" + relation.getName() + "<TYPE>" + relation.getTypeAsString() + "</TYPE></ILR>")
             elif isinstance(relation, SemanticRelation):
                 outFile.write("<SR>" + relation.getName() + "<TYPE>" + relation.getTypeAsString() + "</TYPE></SR>")
+        if self.__wikiPage is not None:
+            outFile.write("<WIKI>" + self.__wikiPage + "</WIKI>")
         if len(self.__definition) > 0:
             outFile.write("<DEF>" + self.getLongDefinition() + "</DEF>")
         if self.__example is not None:
